API reference
=============

.. toctree::
   :maxdepth: 1
   :caption: BOUT++ routines
   :name: api-ref
   :glob:

   user_docs/bout_functions_for_physics
   
   _breathe_autogen/*

.. toctree::
   :maxdepth: 1
   :caption: Python routines
   :name: python-api
   :glob:

   user_docs/python
   _apidoc/*
